@@ -1,7 +1,7 @@
 /*
  * MIT License
  *
- * Copyright (c) 2017-2021 Frank Fischer
+ * Copyright (c) 2017-2022 Frank Fischer
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -98,7 +98,7 @@ fn parse_cpxconst_enum(text: &str) -> HashMap<&str, &str> {
     // We ignore CPX_PARAM_* and use the modern form CPXPARAM_* instead.
     // Furthermore we also parse CPXMIP_* constants as extension to CPX_STAT_*.
     let re_args = Regex::new(&format!(
-        r#"#define\s+CPX((?:_[A-Za-z_]+|(?:MIP|PARAM)_[A-Za-z_]+))\s*([-+eE0-9.]+[lL]*|'[^']'|"[^\n"]*")\n"#
+        r#"#define\s+CPX((?:_[A-Za-z_]+|(?:MIP|PARAM)_[A-Za-z_]+))\s*([-+eE0-9.]+[lL]*|NAN|'[^']'|"[^\n"]*")\n"#
     ))
     .unwrap();
     HashMap::from_iter(re_args.captures_iter(text).filter_map(|caps| {
@@ -138,6 +138,7 @@ fn parse_cplex<W: Write>(filename: &str, constants: &Constants, f: &mut W) -> Re
             .unwrap();
     let re_params = Regex::new(r"(?P<type>\w[^,()]*)(?P<name>\b[0-9a-zA-Z_]+)\s*(?:,|$)|(?P<freturn>\w[^()]*)\(CPXPUBLIC\s*(?P<ftype>\*+)\s*(?P<fname>\w+)\s*\)\s*\((?P<fparams>[^)]*)\)\s*(?:,|$)").unwrap();
 
+    writeln!(f, "use std::f64::NAN;")?;
     writeln!(f, "pub enum Env {{}}")?;
     writeln!(f, "pub enum Lp {{}}")?;
     writeln!(f, "pub enum Net {{}}")?;
@@ -183,7 +184,7 @@ fn parse_cplex<W: Write>(filename: &str, constants: &Constants, f: &mut W) -> Re
             ("&str", &val[..], "")
         } else if val.ends_with("LL") {
             ("c_longlong", &val[..val.len() - 2], "")
-        } else if val.contains('e') || val.contains('E') {
+        } else if val.contains('e') || val.contains('E') || val == &"NAN" {
             ("c_double", &val[..], "")
         } else {
             ("c_int", &val[..], "")
